@@ -105,7 +105,7 @@ public:
 protected:
     void run() override;
 
-signals:
+Q_SIGNALS:
     void done(OpenDBJob*);
 
 public:
@@ -140,7 +140,7 @@ public:
         return m_dbName;
     }
 
-signals:
+Q_SIGNALS:
     void done(CloseDBJob*);
 
 protected:
@@ -169,7 +169,7 @@ public:
         return SELECT;
     }
 
-signals:
+Q_SIGNALS:
     void done(SelectJob*);
 
 protected:
@@ -216,7 +216,7 @@ protected:
 
     QString m_dbName;
 
-signals:
+Q_SIGNALS:
     void done();
 };
 
@@ -238,7 +238,7 @@ protected:
     QString m_dbName;
     QObject m_parent;
 
-signals:
+Q_SIGNALS:
     void done();
 };
 
@@ -259,7 +259,7 @@ protected:
 
     TMEntry m_entry;
 
-signals:
+Q_SIGNALS:
     void done();
 };
 
@@ -338,16 +338,18 @@ public:
     explicit ScanJobFeedingBack(const QString& filePath,
                                 const QString& dbName)
         : QObject(), ScanJob(filePath, dbName)
-    {}
+    {
+        setAutoDelete(false);
+    }
 
 protected:
     void run() override
     {
         ScanJob::run();
-        emit done(this);
+        Q_EMIT done(this);
     }
 
-signals:
+Q_SIGNALS:
     void done(ScanJobFeedingBack*);
 };
 
@@ -367,13 +369,13 @@ public:
         return BATCHSELECTFINISHED;
     }
 
-signals:
+Q_SIGNALS:
     void done();
 
 protected:
     void run() override
     {
-        emit done();
+        Q_EMIT done();
     }
 public:
     QWidget* m_view;
@@ -475,7 +477,7 @@ public:
 
     QSqlQuery* query;
 
-signals:
+Q_SIGNALS:
     void done(ExecQueryJob*);
 
 protected:
