@@ -176,14 +176,14 @@ void TMDBModel::slotQueryExecuted(ExecQueryJob* job)
 
         m_totalResultCount = job->query->next() ? job->query->value(0).toInt() : -1;
         m_dbOperationMutex.unlock();
-        emit finalResultCountFetched(m_totalResultCount);
+        Q_EMIT finalResultCountFetched(m_totalResultCount);
         return;
     }
     query().finish();
     query().clear();
     setQuery(*(job->query));
     m_dbOperationMutex.unlock();
-    emit resultsFetched();
+    Q_EMIT resultsFetched();
 
 }
 
@@ -304,7 +304,7 @@ void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex& parent)
         oldSourceRowCount = sourceModel()->rowCount();
     }
     qCDebug(LOKALIZE_LOG) << "row count" << sourceModel()->rowCount() << "   filtered:" << rowCount();
-    emit layoutChanged();
+    Q_EMIT layoutChanged();
 }
 
 void TMResultsSortFilterProxyModel::setRules(const QVector<Rule>& rules)
@@ -327,13 +327,13 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role)
     int source_row = mapToSource(index).row();
     QString string = result.toString();
 
-    QVector<QRegExp> regExps;
-    if (index.column() == TMDBModel::Source)
-        regExps = m_rules[m_matchingRulesForSourceRow[source_row]].sources;
-    else
-        regExps = m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
+    const QVector<QRegExp> regExps =
+        (index.column() == TMDBModel::Source) ?
+            m_rules[m_matchingRulesForSourceRow[source_row]].sources
+        :
+            m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
 
-    foreach (const QRegExp& re, regExps) {
+    for (const QRegExp& re : regExps) {
         int pos = re.indexIn(string);
         if (pos != -1)
             return string.replace(pos, re.matchedLength(), QStringLiteral("<b>") + re.cap(0) + QStringLiteral("</b>"));
@@ -639,7 +639,7 @@ void TMTab::openFile()
             return performQuery();//We relaunch the query
         }
     }
-    emit fileOpenRequested(item.sibling(item.row(), TMDBModel::Filepath).data(Qt::UserRole).toString(),
+    Q_EMIT fileOpenRequested(item.sibling(item.row(), TMDBModel::Filepath).data(Qt::UserRole).toString(),
                            item.sibling(item.row(), TMDBModel::Source).data().toString(),
                            item.sibling(item.row(), TMDBModel::Context).data().toString(),
                            true);
@@ -725,7 +725,8 @@ void TMTab::dragEnterEvent(QDragEnterEvent* event)
 void TMTab::dropEvent(QDropEvent *event)
 {
     QStringList files;
-    foreach (const QUrl& url, event->mimeData()->urls())
+    const auto urls = event->mimeData()->urls();
+    for (const QUrl& url : urls)
         files.append(url.toLocalFile());
 
     if (scanRecursive(files, Project::instance()->projectID()))
